@@ -1,3 +1,39 @@
+//-----------------------------------------------------------------------------
+//
+// Copyright (c) 1998 - 2007, The Regents of the University of California
+// Produced at the Lawrence Livermore National Laboratory
+// All rights reserved.
+//
+// This file is part of PyCXX. For details,see http://cxx.sourceforge.net/. The
+// full copyright notice is contained in the file COPYRIGHT located at the root
+// of the PyCXX distribution.
+//
+// Redistribution  and  use  in  source  and  binary  forms,  with  or  without
+// modification, are permitted provided that the following conditions are met:
+//
+//  - Redistributions of  source code must  retain the above  copyright notice,
+//    this list of conditions and the disclaimer below.
+//  - Redistributions in binary form must reproduce the above copyright notice,
+//    this  list of  conditions  and  the  disclaimer (as noted below)  in  the
+//    documentation and/or materials provided with the distribution.
+//  - Neither the name of the UC/LLNL nor  the names of its contributors may be
+//    used to  endorse or  promote products derived from  this software without
+//    specific prior written permission.
+//
+// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT  HOLDERS AND CONTRIBUTORS "AS IS"
+// AND ANY EXPRESS OR  IMPLIED WARRANTIES, INCLUDING,  BUT NOT  LIMITED TO, THE
+// IMPLIED WARRANTIES OF MERCHANTABILITY AND  FITNESS FOR A PARTICULAR  PURPOSE
+// ARE  DISCLAIMED.  IN  NO  EVENT  SHALL  THE  REGENTS  OF  THE  UNIVERSITY OF
+// CALIFORNIA, THE U.S.  DEPARTMENT  OF  ENERGY OR CONTRIBUTORS BE  LIABLE  FOR
+// ANY  DIRECT,  INDIRECT,  INCIDENTAL,  SPECIAL,  EXEMPLARY,  OR CONSEQUENTIAL
+// DAMAGES (INCLUDING, BUT NOT  LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR
+// SERVICES; LOSS OF  USE, DATA, OR PROFITS; OR  BUSINESS INTERRUPTION) HOWEVER
+// CAUSED  AND  ON  ANY  THEORY  OF  LIABILITY,  WHETHER  IN  CONTRACT,  STRICT
+// LIABILITY, OR TORT  (INCLUDING NEGLIGENCE OR OTHERWISE)  ARISING IN ANY  WAY
+// OUT OF THE  USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
+// DAMAGE.
+//
+//-----------------------------------------------------------------------------
 #include "CXX/Extensions.hxx"
 #include "CXX/Exception.hxx"
 
@@ -48,7 +84,7 @@ PyMethodDef* MethodTable::table()
 {    
     if( !mt )
     {
-        int t1size = t.size();
+        Py_ssize_t t1size = t.size();
         mt = new PyMethodDef[t1size];
         int j = 0;
         for( std::vector<PyMethodDef>::iterator i = t.begin(); i != t.end(); i++ )
@@ -145,8 +181,8 @@ extern "C"
     static PyObject* str_handler (PyObject*);
     static long hash_handler (PyObject*);
     static PyObject* call_handler (PyObject*, PyObject*, PyObject*);
-        static PyObject* iter_handler (PyObject*);
-        static PyObject* iternext_handler (PyObject*);
+    static PyObject* iter_handler (PyObject*);
+    static PyObject* iternext_handler (PyObject*);
 
     // Sequence methods
     static Py_ssize_t sequence_length_handler(PyObject*);
@@ -189,7 +225,7 @@ extern "C"
     static Py_ssize_t buffer_getreadbuffer_handler (PyObject*, Py_ssize_t, void**);
     static Py_ssize_t buffer_getwritebuffer_handler (PyObject*, Py_ssize_t, void**);
     static Py_ssize_t buffer_getsegcount_handler (PyObject*, Py_ssize_t*);
-};
+}
 
 
 extern "C" void standard_dealloc( PyObject* p )
@@ -197,7 +233,7 @@ extern "C" void standard_dealloc( PyObject* p )
     PyMem_DEL( p );
 }
 
-void PythonType::supportSequenceType()
+PythonType & PythonType::supportSequenceType()
 {
     if( !sequence_table )
     {
@@ -211,11 +247,12 @@ void PythonType::supportSequenceType()
         sequence_table->sq_slice = sequence_slice_handler;
 
         sequence_table->sq_ass_item = sequence_ass_item_handler;    // BAS setup seperately?
-        sequence_table->sq_ass_slice = sequence_ass_slice_handler;    // BAS setup seperately?
+        sequence_table->sq_ass_slice = sequence_ass_slice_handler;  // BAS setup seperately?
     }
+    return *this;
 }
 
-void PythonType::supportMappingType()
+PythonType & PythonType::supportMappingType()
 {
     if( !mapping_table )
     {
@@ -226,9 +263,10 @@ void PythonType::supportMappingType()
         mapping_table->mp_subscript = mapping_subscript_handler;
         mapping_table->mp_ass_subscript = mapping_ass_subscript_handler;    // BAS setup seperately?
     }
+    return *this;
 }
 
-void PythonType::supportNumberType()
+PythonType & PythonType::supportNumberType()
 {
     if( !number_table )
     {
@@ -259,9 +297,10 @@ void PythonType::supportNumberType()
         number_table->nb_oct = number_oct_handler;
         number_table->nb_hex = number_hex_handler;
     }
+    return *this;
 }
 
-void PythonType::supportBufferType()
+PythonType & PythonType::supportBufferType()
 {
     if( !buffer_table )
     {
@@ -272,6 +311,7 @@ void PythonType::supportBufferType()
         buffer_table->bf_getwritebuffer = buffer_getwritebuffer_handler;
         buffer_table->bf_getsegcount = buffer_getsegcount_handler;
     }
+    return *this;
 }
 
 // if you define one sequence method you must define 
@@ -346,14 +386,15 @@ PythonType::~PythonType( )
     delete mapping_table;
     delete number_table;
     delete buffer_table;
-};
+}
 
 PyTypeObject* PythonType::type_object( ) const
 {return table;}
 
-void PythonType::name( const char* nam )
+PythonType & PythonType::name( const char* nam )
 {
     table->tp_name = const_cast<char *>( nam );
+    return *this;
 }
 
 const char *PythonType::getName() const
@@ -361,9 +402,10 @@ const char *PythonType::getName() const
     return table->tp_name;
 }
 
-void PythonType::doc( const char* d )
+PythonType & PythonType::doc( const char* d )
 {
     table->tp_doc = const_cast<char *>( d );
+    return *this;
 }
 
 const char *PythonType::getDoc() const
@@ -371,65 +413,77 @@ const char *PythonType::getDoc() const
     return table->tp_doc;
 }
 
-void PythonType::dealloc( void( *f )( PyObject* ))
+PythonType & PythonType::dealloc( void( *f )( PyObject* ))
 {
     table->tp_dealloc = f;
+    return *this;
 }
 
-void PythonType::supportPrint()
+PythonType & PythonType::supportPrint()
 {
     table->tp_print = print_handler;
+    return *this;
 }
 
-void PythonType::supportGetattr()
+PythonType & PythonType::supportGetattr()
 {
     table->tp_getattr = getattr_handler;
+    return *this;
 }
 
-void PythonType::supportSetattr()
+PythonType & PythonType::supportSetattr()
 {
     table->tp_setattr = setattr_handler;
+    return *this;
 }
 
-void PythonType::supportGetattro()
+PythonType & PythonType::supportGetattro()
 {
     table->tp_getattro = getattro_handler;
+    return *this;
 }
 
-void PythonType::supportSetattro()
+PythonType & PythonType::supportSetattro()
 {
     table->tp_setattro = setattro_handler;
+    return *this;
 }
 
-void PythonType::supportCompare()
+PythonType & PythonType::supportCompare()
 {
     table->tp_compare = compare_handler;
+    return *this;
 }
 
-void PythonType::supportRepr()
+PythonType & PythonType::supportRepr()
 {
     table->tp_repr = repr_handler;
+    return *this;
 }
 
-void PythonType::supportStr()
+PythonType & PythonType::supportStr()
 {
     table->tp_str = str_handler;
+    return *this;
 }
 
-void PythonType::supportHash()
+PythonType & PythonType::supportHash()
 {
     table->tp_hash = hash_handler;
+    return *this;
 }
 
-void PythonType::supportCall()
+PythonType & PythonType::supportCall()
 {
     table->tp_call = call_handler;
+    return *this;
 }
 
-void PythonType::supportIter()
+PythonType & PythonType::supportIter()
 {
     table->tp_iter = iter_handler;
-        table->tp_iternext = iternext_handler;
+    table->tp_iternext = iternext_handler;
+    return *this;
 }
 
 //--------------------------------------------------------------------------------
@@ -559,11 +613,10 @@ extern "C" PyObject* call_handler( PyObject *self, PyObject *args, PyObject *kw
     try
     {
         PythonExtensionBase *p = static_cast<PythonExtensionBase *>( self );
-        return new_reference_to( p->call( Py::Object( args ), Py::Object( kw ) ) );
         if( kw != NULL )
-        return new_reference_to( p->call( Py::Object( args ), Py::Object( kw ) ) );
+            return new_reference_to( p->call( Py::Object( args ), Py::Object( kw ) ) );
         else
-        return new_reference_to( p->call( Py::Object( args ), Py::Object() ) );
+            return new_reference_to( p->call( Py::Object( args ), Py::Object() ) );
     }
     catch( Py::Exception & )
     {
@@ -1116,19 +1169,19 @@ int PythonExtensionBase::sequence_length()
 Py::Object PythonExtensionBase::sequence_concat( const Py::Object & )
 { missing_method( sequence_concat ); return Py::Nothing(); }
 
-Py::Object PythonExtensionBase::sequence_repeat( int )
+Py::Object PythonExtensionBase::sequence_repeat( Py_ssize_t )
 { missing_method( sequence_repeat ); return Py::Nothing(); }
 
-Py::Object PythonExtensionBase::sequence_item( int )
+Py::Object PythonExtensionBase::sequence_item( Py_ssize_t )
 { missing_method( sequence_item ); return Py::Nothing(); }
 
-Py::Object PythonExtensionBase::sequence_slice( int, int )
+Py::Object PythonExtensionBase::sequence_slice( Py_ssize_t, Py_ssize_t )
 { missing_method( sequence_slice ); return Py::Nothing(); }
 
-int PythonExtensionBase::sequence_ass_item( int, const Py::Object & )
+int PythonExtensionBase::sequence_ass_item( Py_ssize_t, const Py::Object & )
 { missing_method( sequence_ass_item ); return -1; }
 
-int PythonExtensionBase::sequence_ass_slice( int, int, const Py::Object & )
+int PythonExtensionBase::sequence_ass_slice( Py_ssize_t, Py_ssize_t, const Py::Object & )
 { missing_method( sequence_ass_slice ); return -1; }
 
 
